@@ -21,7 +21,11 @@
 */
 
 #include <config.h>
-#include <libgnome/gnome-i18n.h>
+#ifdef GNOME_GTKHTML_EDITOR_SHLIB
+#include <glib/gi18n-lib.h>
+#else
+#include <glib/gi18n.h>
+#endif
 #include <string.h>
 #include <glade/glade.h>
 #include "gi-color-combo.h"
@@ -39,6 +43,7 @@
 #include "htmltable.h"
 #include "htmltablecell.h"
 #include "htmlsettings.h"
+#include "gtkhtml-private.h"
 
 #include "properties.h"
 #include "cell.h"
@@ -84,9 +89,9 @@ data_new (GtkHTMLControlData *cd, HTMLTableCell *cell)
 	data->cd = cd;
 	data->scope = CELL_SCOPE_CELL;
 	data->cell = cell;
-	g_return_if_fail (data->cell);
+	g_return_val_if_fail (data->cell, NULL);
 	data->table = HTML_TABLE (HTML_OBJECT (data->cell)->parent);
-	g_return_if_fail (data->table && HTML_IS_TABLE (data->table));
+	g_return_val_if_fail (data->table && HTML_IS_TABLE (data->table), NULL);
 
 	return data;
 }
@@ -150,7 +155,7 @@ cell_set_prop (GtkHTMLEditCellProperties *d, void (*set_fn)(HTMLTableCell *, Gtk
 static void
 set_bg_color (HTMLTableCell *cell, GtkHTMLEditCellProperties *d)
 {
-	html_engine_table_cell_set_bg_color (d->cd->html->engine, cell, color_combo_get_color (COLOR_COMBO (d->combo_bg_color), NULL));
+	html_engine_table_cell_set_bg_color (d->cd->html->engine, cell, gi_color_combo_get_color (GI_COLOR_COMBO (d->combo_bg_color), NULL));
 }
 
 static void
@@ -165,9 +170,8 @@ set_bg_pixmap (HTMLTableCell *cell, GtkHTMLEditCellProperties *d)
 	const char *file;
 	char *url = NULL;
 
-	file = gtk_entry_get_text (GTK_ENTRY (gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (d->entry_bg_pixmap))));
-	if (file && *file)
-		url = g_strconcat ("file://", file, NULL);
+	file = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (d->entry_bg_pixmap));
+	url = gtk_html_filename_to_uri (file);
 
 	html_engine_table_cell_set_bg_pixmap (d->cd->html->engine, cell, url);
 	g_free (url);
@@ -327,8 +331,11 @@ cell_widget (GtkHTMLEditCellProperties *d)
 {
 	GtkWidget *cell_page;
 	GladeXML *xml;
+	gchar *filename;
 
-	xml = glade_xml_new (GLADE_DATADIR "/gtkhtml-editor-properties.glade", "cell_page", GETTEXT_PACKAGE);
+	filename = g_build_filename (GLADE_DATADIR, "gtkhtml-editor-properties.glade", NULL);
+	xml = glade_xml_new (filename, "cell_page", GETTEXT_PACKAGE);
+	g_free (filename);
 	if (!xml)
 		g_error (_("Could not load glade file."));
 
@@ -337,25 +344,31 @@ cell_widget (GtkHTMLEditCellProperties *d)
 	gtk_table_attach (GTK_TABLE (glade_xml_get_widget (xml, "cell_scope_table1")),
 			  gtk_image_new_from_file (gnome_icon_theme_lookup_icon (d->cd->icon_theme, "stock_select-cell", 16, NULL, NULL)),
 			  0, 1, 0, 1, 0, 0, 0, 0);
+	filename = g_build_filename (ICONDIR, "table-table-16.png", NULL);
 	gtk_table_attach (GTK_TABLE (glade_xml_get_widget (xml, "cell_scope_table1")),
-			  gtk_image_new_from_file (ICONDIR "/table-table-16.png"),
+			  gtk_image_new_from_file (filename),
 			  0, 1, 1, 2, 0, 0, 0, 0);
+	g_free (filename);
+	filename = g_build_filename (ICONDIR, "table-row-16.png", NULL);
 	gtk_table_attach (GTK_TABLE (glade_xml_get_widget (xml, "cell_scope_table2")),
-			  gtk_image_new_from_file (ICONDIR "/table-row-16.png"),
+			  gtk_image_new_from_file (filename),
 			  0, 1, 0, 1, 0, 0, 0, 0);
+	g_free (filename);
+	filename = g_build_filename (ICONDIR, "table-column-16.png", NULL);
 	gtk_table_attach (GTK_TABLE (glade_xml_get_widget (xml, "cell_scope_table2")),
-			  gtk_image_new_from_file (ICONDIR "/table-column-16.png"),
+			  gtk_image_new_from_file (filename),
 			  0, 1, 1, 2, 0, 0, 0, 0);
+	g_free (filename);
 
-	d->combo_bg_color = color_combo_new (NULL, _("Transparent"), NULL,
+	d->combo_bg_color = gi_color_combo_new (NULL, _("Transparent"), NULL,
 					     color_group_fetch ("cell_bg_color", d->cd));
-        color_combo_box_set_preview_relief (COLOR_COMBO (d->combo_bg_color), GTK_RELIEF_NORMAL); \
+        gi_color_combo_box_set_preview_relief (GI_COLOR_COMBO (d->combo_bg_color), GTK_RELIEF_NORMAL); \
         g_signal_connect (d->combo_bg_color, "color_changed", G_CALLBACK (changed_bg_color), d);
 	gtk_box_pack_start (GTK_BOX (glade_xml_get_widget (xml, "bg_color_hbox")), d->combo_bg_color, FALSE, FALSE, 0);
 
 	d->entry_bg_pixmap = glade_xml_get_widget (xml, "entry_cell_bg_pixmap");
-	g_signal_connect (gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (d->entry_bg_pixmap)),
-			    "changed", G_CALLBACK (changed_bg_pixmap), d);
+	g_signal_connect (GTK_FILE_CHOOSER_BUTTON (d->entry_bg_pixmap),
+			    "selection-changed", G_CALLBACK (changed_bg_pixmap), d);
 
 	d->option_halign = glade_xml_get_widget (xml, "option_cell_halign");
 	g_signal_connect (gtk_option_menu_get_menu (GTK_OPTION_MENU (d->option_halign)), "selection-done",
@@ -389,7 +402,7 @@ cell_widget (GtkHTMLEditCellProperties *d)
 	g_signal_connect (d->spin_rspan, "value_changed", G_CALLBACK (changed_rspan), d);
 
 	gtk_widget_show_all (cell_page);
-	gnome_pixmap_entry_set_preview (GNOME_PIXMAP_ENTRY (d->entry_bg_pixmap), FALSE);
+	gtk_file_chooser_set_preview_widget_active (GTK_FILE_CHOOSER (d->entry_bg_pixmap), FALSE);
 
 	return cell_page;
 }
@@ -403,17 +416,14 @@ set_ui (GtkHTMLEditCellProperties *d)
 	d->disable_change = TRUE;
 
 	if (d->cell->have_bg)
-		color_combo_set_color (COLOR_COMBO (d->combo_bg_color), &d->cell->bg);
+		gi_color_combo_set_color (GI_COLOR_COMBO (d->combo_bg_color), &d->cell->bg);
 
 	if (d->cell->have_bgPixmap) {
-		int off = 0;
+		char *filename = gtk_html_filename_from_uri (d->cell->bgPixmap->url);
 
-		if (!strncasecmp ("file://", d->cell->bgPixmap->url, 7))
-			off = 7;
-		else if (!strncasecmp ("file:", d->cell->bgPixmap->url, 5))
-			off = 5;
-		gtk_entry_set_text (GTK_ENTRY (gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (d->entry_bg_pixmap))),
-				    d->cell->bgPixmap->url + off);
+		gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (d->entry_bg_pixmap),
+				    filename);
+		g_free (filename);
 	}
 
 	if (HTML_CLUE (d->cell)->halign == HTML_HALIGN_NONE)
